Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(740)

Unified Diff: content/renderer/render_process_impl.cc

Issue 2710713004: Revert "Use the Windows MDM API to check if the machine is being managed." (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/update_client/utils.cc ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/render_process_impl.cc
diff --git a/content/renderer/render_process_impl.cc b/content/renderer/render_process_impl.cc
index ede64934c0f65656d0c59ba4cf209c2ee94dfb55..39819457dbb0bf474d116f0d29d6445a632643c5 100644
--- a/content/renderer/render_process_impl.cc
+++ b/content/renderer/render_process_impl.cc
@@ -139,12 +139,12 @@ RenderProcessImpl::RenderProcessImpl(
std::move(worker_pool_index_for_traits_callback)),
enabled_bindings_(0) {
#if defined(OS_WIN)
// Record whether the machine is enterprise managed in a crash key. This
// will be used to better identify whether crashes are from enterprise users.
// Note that this is done very early on so that crashes have the highest
// chance of getting tagged.
- base::debug::SetCrashKeyValue(
- "is-enterprise-managed", base::win::IsEnterpriseManaged() ? "yes" : "no");
+ base::debug::SetCrashKeyValue("enrolled-to-domain",
+ base::win::IsEnrolledToDomain() ? "yes" : "no");
// HACK: See http://b/issue?id=1024307 for rationale.
if (GetModuleHandle(L"LPK.DLL") == NULL) {
« no previous file with comments | « components/update_client/utils.cc ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
@@ -139,12 +139,12 @@ RenderProcessImpl::RenderProcessImpl(
enabled_bindings_(0) {
#if defined(OS_WIN)
- // Record whether the machine is enterprise managed in a crash key. This
- // will be used to better identify whether crashes are from enterprise users.
+ // Record whether the machine is domain joined in a crash key. This will be
+ // used to better identify whether crashes are from enterprise users.
// Note that this is done very early on so that crashes have the highest
// chance of getting tagged.

Powered by Google App Engine
This is Rietveld 408576698